Index: /extensions/ExtendedDescription/admin.php
===================================================================
--- /extensions/ExtendedDescription/admin.php	(revision 29128)
+++ /extensions/ExtendedDescription/admin.php	(revision 29129)
@@ -18,4 +18,5 @@
     'hide' =>       load_language('help.hide.html', EXTENDED_DESC_PATH, array('return'=>true)),
     'redirect' =>   load_language('help.redirect.html', EXTENDED_DESC_PATH, array('return'=>true)),
+    'logged' =>     load_language('help.logged.html', EXTENDED_DESC_PATH, array('return'=>true)),
     ),
   ));
Index: tensions/ExtendedDescription/changelog.txt
===================================================================
--- /extensions/ExtendedDescription/changelog.txt	(revision 29128)
+++ 	(revision )
@@ -1,35 +1,0 @@
-| date       | release |
-|------------|---------|------------------------------------------------------------
-|            | 2.0.c   | P@t
-|            |         |
-| 2009-04-01 | 2.0.d   | Grum
-|            |         | * bug corrected, markup <!--hidden--> now works again
-|            |         |   on categories name
-|            |         | * new functionality, can use a markup <!--hidden-->
-|            |         |   on image's name
-|            |         | * new functionality, add a new parameter for the image
-|            |         |   markup [img=] ; possibility to show the image name
-|            |         |   with the "name" parameter
-|            |         | * new functionality, the image markup [img=] allows now
-|            |         |   to display more than one image
-|            |         |
-| 2009-04-30 | 2.0.e   | P@t
-|            |         | * bug corrected, avoid errors on categories pages when
-|            |         |   $conf['show_thumbnail_caption'] = false
-|            |         |
-| 2009-05-10 | 2.0.f   | P@t
-|            |         | * add possibility to remove a category from menubar
-|            |         |   with markup <!--mb-hidden-->
-|            |         |
-| 2010-25-09 | 2.0.g   | Grum
-|            |         | * possibility to display the picture's name into the
-|            |         |   image title ('titleName' parameter) rather than under
-|            |         |    the picture ('name' parameter)
-|            |         | * add Id for image & anchor for [img=...] markup
-|            |         |
-| 2010-12-27 | 2.1.e   | P@t
-|            |         | * add redirect tag
-|            |         |
-| 2011-05-04 | 2.2.a   | P@t
-|            |         | * 2.2.x compatibility (top and bottom descriptions)
-|            |         |
Index: /extensions/ExtendedDescription/include/admin.inc.php
===================================================================
--- /extensions/ExtendedDescription/include/admin.inc.php	(revision 29128)
+++ /extensions/ExtendedDescription/include/admin.inc.php	(revision 29129)
@@ -73,4 +73,5 @@
         'hide' =>       load_language('help.hide.html', EXTENDED_DESC_PATH, array('return'=>true)),
         'redirect' =>   load_language('help.redirect.html', EXTENDED_DESC_PATH, array('return'=>true)),
+        'logged' =>     load_language('help.logged.html', EXTENDED_DESC_PATH, array('return'=>true)),
         ),
       ));
Index: /extensions/ExtendedDescription/include/events.inc.php
===================================================================
--- /extensions/ExtendedDescription/include/events.inc.php	(revision 29128)
+++ /extensions/ExtendedDescription/include/events.inc.php	(revision 29129)
@@ -79,4 +79,26 @@
   OR name LIKE \'%]'.$str.'[/lang]%\'';
   return $where;
+}
+
+/**
+ * Parse [logged] tag
+ */
+function get_loggedin_desc($desc)
+{
+  $patterns[] = '#\[logged(?:=true|=yes)?\](.*?)\[/logged\]#is';
+  $patterns[] = '#\[logged(?:=false|=no)\](.*?)\[/logged\]#is';
+  
+  if (is_a_guest())
+  {
+    $replacements[] = '';
+    $replacements[] = '\\1';
+  }
+  else
+  {
+    $replacements[] = '\\1';
+    $replacements[] = '';
+  }
+
+  return preg_replace($patterns, $replacements, $desc);
 }
 
@@ -137,4 +159,5 @@
   }
 
+  $desc = get_loggedin_desc($desc);
   $desc = get_user_language_desc($desc);
 
@@ -148,5 +171,6 @@
   // [random album=xx size=SQ|TH|XXS|XS|S|M|L|XL|XXL html=yes|no link=yes|no]
   // [slider album=xx nb_images=yy random=yes|no list=aa,bb,cc size=SQ|TH|XXS|XS|S|M|L|XL|XXL speed=z title=yes|no effect=... arrows=yes|no control=yes|no|thumb elastic=yes|no thumbs_size=dd]
-  $generic_pattern = '#\[(cat=|img|photo|random|slider)([^\]]*)\]#i';
+  // [login-link html=yes|no text="log in[lang=fr]connectez-vous[/lang]"]
+  $generic_pattern = '#\[(cat=|img|photo|random|slider|login-link)([^\]]*)\]#i';
 
   // <!--complete-->, <!--more--> et <!--up-down-->
@@ -185,5 +209,5 @@
   {
     case 'cat=':
-      return get_cat_thumb($matches[2]);
+      return extdesc_get_cat_thumb($matches[2]);
       break;
       
@@ -193,5 +217,5 @@
       
     case 'photo':
-      return get_photo_sized($matches[2]);
+      return extdesc_get_photo_sized($matches[2]);
       break;
       
@@ -201,5 +225,9 @@
       
     case 'slider':
-      return get_slider($matches[2]);
+      return extdesc_get_slider($matches[2]);
+      break;
+    
+    case 'login-link':
+      return extdesc_get_login_link($matches[2]);
       break;
   }
Index: /extensions/ExtendedDescription/language/ar_SA/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/ar_SA/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/ar_SA/help.lang.html	(revision 29129)
@@ -1,13 +1,4 @@
 <p>متعدد اللغات يوضع بين[lang=xx] و [/lang]
 دلائل, حيث xx هو رمزاللغة (مثال  en, es, fr). هنالك ايضا لغتين خاصتين : [lang=default] and [lang=all]</p>
-
-<ul>
-<li><b>مثال</b>:<br>
-<br>
-<code>[lang=default] الوصف الافتراضي [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>وسيتم استخدام الوصف الافتراضي إذا كان الوصف ليس
@@ -18,2 +9,8 @@
 يدخل بالوصف, باي لغة يعرف المستخدم
 هذا مفيد في HTML/JavaScript code داخل الوصف.</p>
+
+<p><b>مثال</b>:<br>
+<code>[lang=default] الوصف الافتراضي [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/bg_BG/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/bg_BG/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/bg_BG/help.lang.html	(revision 29129)
@@ -3,14 +3,12 @@
 <p>Многоезиково описание е поставеното между [lang=xx] and [/lang] тагове, където xx е езиковия код (за пример en, es, fr, bg ...). Има също така два специални езика : [lang=default] и [lang=all]</p>
 
-<ul>
-  <li><b>Примери</b>:<br>
+<p>"default" описанието ще бъде използвано по подразбиране там където не е въведено друго описание на езика на който отворил потребител на вашата галерия. Ако [lang=default] не съществува, всичко написано извън тага [lang] ще се приема за описание по подразбиране.</p>
+
+<p><u>Специален език <i>all</i></u>: всичко в [lang=all] ще се приеме за описание, БЕЗ да има значение какво е описанието за конкретния език на потребителя на галерията. Това е удобно при използване на HTML/JavaScript код вътре в описанието.</p>
+
+<p><b>Примери</b>:<br>
 <code>[lang=default] default description [/lang]<br>
 [lang=en] description in english [/lang]<br>
 [lang=de] deutsche Beschreibung [/lang]<br>
 [lang=bg] описание на Български [/lang]</code>
-</li>
-</ul>
-
-<p>"default" описанието ще бъде използвано по подразбиране там където не е въведено друго описание на езика на който отворил потребител на вашата галерия. Ако [lang=default] не съществува, всичко написано извън тага [lang] ще се приема за описание по подразбиране.</p>
-
-<p><u>Специален език <i>all</i></u>: всичко в [lang=all] ще се приеме за описание, БЕЗ да има значение какво е описанието за конкретния език на потребителя на галерията. Това е удобно при използване на HTML/JavaScript код вътре в описанието.</p>
+</p>
Index: /extensions/ExtendedDescription/language/ca_ES/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/ca_ES/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/ca_ES/help.lang.html	(revision 29129)
@@ -1,14 +1,4 @@
 <p>Les descripcions multilingües es col·loquen entre les etiquetes [lang=xx] i [/lang], O xx és el códi de l'idioma (per exemple ca, fr, en, es, it, de...)
 Existeixen també 2 etiquetes especials: [lang=default] i [lang=all]</p>
-
-<ul>
-  <li><b>Exemple d'utilització:</b>:<br>
-  <br>
-<code>[lang=default] Descripció predeterminada [/lang]<br>
-[lang=ca] Descripció en català [/lang]<br>
-[lang=fr] Descripción ello francais [/lang]<br>
-[lang=it] Descripción en italiano [/lang]</code>
-</li>
-</ul>
 
 <p>La descripció predeterminada s'utilitza si la descripció no està disponible en l'idioma que l'usuari ha seleccionat.
@@ -17,2 +7,9 @@
 <p><u>Etiqueta especial  <i>all</i></u>: Tot el que estigui situat entre les etiquetes [lang=all] i [/lang] serà inclòs en la descripció, sigui quin sigui l'idioma de l'usuari.
 Això és especialment pràctic per a incloure codi html o javascript en una descripció.</p>
+
+<p><b>Exemple d'utilització:</b>:<br>
+<code>[lang=default] Descripció predeterminada [/lang]<br>
+[lang=ca] Descripció en català [/lang]<br>
+[lang=fr] Descripción ello francais [/lang]<br>
+[lang=it] Descripción en italiano [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/cs_CZ/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/cs_CZ/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/cs_CZ/help.lang.html	(revision 29129)
@@ -1,13 +1,3 @@
 <p>Vícejazyčné popisy jsou umístěny mezi elementy [lang=xx] a [/lang], kde xx je kód jazyka (například cs, en, es, fr). Dále jsou 2 speciální kódy jazyka: [lang=default] a [lang=all]</p>
-
-<ul>
-  <li><b>Příklad</b>:<br>
-  <br>
-<code>[lang=default] default description [/lang]<br>
-[lang=cs] popis v češtině [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Výchozí popis bude použit v případě, že popis není dostupný v daném jazyce.
@@ -16,2 +6,9 @@
 <p><u>Speciální jazyk <i>all</i></u>: všechno co je uvedeno uvnitř [lang=all] vždy bude vloženo do popisu bez ohledu na zvolený jazyk.
 Toto je užitečné zejména pro vkládání kódu HTML/JavaScript do popisu.</p>
+
+<p><b>Příklad</b>:<br>
+<code>[lang=default] default description [/lang]<br>
+[lang=cs] popis v češtině [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/da_DK/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/da_DK/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/da_DK/help.lang.html	(revision 29129)
@@ -1,12 +1,3 @@
 <p>Flersprogede beskrivelser er placeret mellem tag'ene [lang=xx] og [/lang], hvor xx er sprogkoden (for eksempel en, da, fr). Der er også to særlige sprog: [lang=default] og [lang=all]</p>
-
-<ul>
-  <li><b>Eksempel</b>:<br>
-  <br>
-<code>[lang=default] standardbeskrivelse [/lang]<br>
-[lang=da] beskrivelse på dansk [/lang]<br>
-[lang=en] description in English [/lang]</code>
-</li>
-</ul>
 
 <p>Standardbeskrivelse anvendes hvis der ikke er en beskrivelse tilgængelig i den indloggede brugers sprog.
@@ -15,2 +6,8 @@
 <p><u>Særlige sprog <i>all</i></u>: alt inden for [lang=all] vil blive medtaget i beskrivelsen, uanset hvad den indloggede brugers sprog er opsat som.
 Dette er især nyttigt til at medtage HTML-/JavaScript-kode i en beskrivelse.</p>
+
+<p><b>Eksempel</b>:<br>
+<code>[lang=default] standardbeskrivelse [/lang]<br>
+[lang=da] beskrivelse på dansk [/lang]<br>
+[lang=en] description in English [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/de_DE/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/de_DE/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/de_DE/help.lang.html	(revision 29129)
@@ -1,14 +1,11 @@
 <p>Mehrsprachige Beschreibungen werden zwischen [lang=xx] und [/lang] gesetzt, dabei ist xx der Sprachcode (Zum Beispiel en, de, fr). Es gibt auch noch 2 speziell definierte Sprachen : [lang=default] und [lang=all]</p>
-
-<ul>
-  <li><strong>Beispiel</strong>:<br>
-  <br>
-<code>[lang=default] default description [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Sollte die Beschreibung in der vom Benutzer benützten Sprache nicht vorhanden sein, so wird automatische die standardmässige Beschreibung benützt. Sollte  [lang=default] auch nicht vorhanden sein, so wird alles was ausserhalb des [lang] Tags ist als standardmässige Beschreibung benützt.</p>
 
 <p><u>Spezialsprache <i>all</i></u>: Alles was sich innerhalb [lang=all] befindet wird in der Beschreibung angezeigt, unabhängig davon in welcher Sprache sich ein Benutzer angemeldet hat. Dies kann nützlich sein, um zum Beispiel HTML/Javascript in einer Beschreibung anzuzeigen.</p>
+
+<p><b>Beispiel</b>:<br>
+<code>[lang=default] default description [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/el_GR/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/el_GR/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/el_GR/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Οι πολυγλωσσικές περιγραφές τοποθετούνται μεταξύ των ετικετών [lang=xx] και [/lang], όπου xx είναι ο κωδικός της γλώσσας (για παράδειγμα en, es, fr). Υπάρχουν επίσης 2 ειδικές γλώσσες : [lang=default] και [lang=all]</p>
-
-<ul>
-  <li><b>Παράδειγμα</b>:<br>
-<code>[lang=default] Προεπιλεγμένη περιγραφή  [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Η προεπιλεγμένη περιγραφή θα χρησιμοποιηθεί αν η περιγραφή δεν είναι διαθέσιμη στο συνδεδεμένο χρήστη που έχει επιλέξει γλώσσα.
@@ -14,2 +6,8 @@
 <p><u>Ειδική γλώσσα <i>όλα</i></u>: οτιδήποτε μέσα στο [lang=all] θα πρέπει να περιλαμβάνεται στην περιγραφή, για οποιονδήποτε συνδεδεμένο χρήστη που έχει επιλέξει γλώσσα.
 Αυτό είναι χρήσιμο κυρίως για να συμπεριλάβει HTML / JavaScript κώδικα μέσα σε μια περιγραφή.</p>
+
+<p><b>Παράδειγμα</b>:<br>
+<code>[lang=default] Προεπιλεγμένη περιγραφή  [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/en_UK/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/en_UK/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/en_UK/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Multilingual descriptions are placed between [lang=xx] and [/lang] tags, where xx is the language code (for example en, es, fr). There are also 2 special languages : [lang=default] and [lang=all]</p>
-
-<ul>
-  <li><b>Example</b>:<br>
-<code>[lang=default] default description [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>The default description will be used if the description is not available in the connected user selected language.
@@ -14,2 +6,8 @@
 <p><u>Special language <i>all</i></u>: anything inside [lang=all] will be included in the description, whatever the connected user defined language is.
 This is mainly useful to include HTML/JavaScript code inside a description.</p>
+
+<p><b>Example</b>:<br>
+<code>[lang=default] default description [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/en_UK/help.logged.html
===================================================================
--- /extensions/ExtendedDescription/language/en_UK/help.logged.html	(revision 29129)
+++ /extensions/ExtendedDescription/language/en_UK/help.logged.html	(revision 29129)
@@ -0,0 +1,18 @@
+<ul>
+  <li><b>[login-link html=true text="log in[lang=fr]connectez-vous[/lang]"]</b></li>
+</ul>
+
+<p>This tag allow to insert everywhere a login link with automatic redirection to the current age.<br><br>
+- <code>html</code> (optional) if set to <i>false</i> the tag only returns the login URL, without HTML<br>
+- <code>text</code> (optional) link label, can contain <code>[lang]</code> tags<p>
+
+<ul>
+  <li><b>[logged]</b></li>
+</ul>
+
+<p>Display a block of text only if the current user is logged or not.</p>
+
+<p><b>Example</b>:<br>
+<code>[logged] Welcome back [/logged]<br>
+[logged=false] Please log in [/logged]</code>
+</p>
Index: /extensions/ExtendedDescription/language/en_UK/plugin.lang.php
===================================================================
--- /extensions/ExtendedDescription/language/en_UK/plugin.lang.php	(revision 29128)
+++ /extensions/ExtendedDescription/language/en_UK/plugin.lang.php	(revision 29129)
@@ -10,4 +10,3 @@
 $lang['Hide elements'] = 'Hide elements';
 $lang['Redirect elements'] = 'Redirect elements';
-
-?>
+$lang['Login link & logged in block'] = 'Login link & logged in block';
Index: /extensions/ExtendedDescription/language/eo_EO/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/eo_EO/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/eo_EO/help.lang.html	(revision 29129)
@@ -1,12 +1,3 @@
 <p>Pluralingvaj priskriboj troviĝas inter la etikedoj [lang=xx] kaj [/lang], kie xx estas la lingva kodo (ekzemple eo, en, es, fr). Estas ankaŭ 2 specialaj lingvoj: [lang=default] kaj [lang=all]</p>
-
-<ul>
-  <li><b>Ekzemple</b>:<br>
-<code>[lang=default] apriora priskribo [/lang]<br>
-[lang=eo] priskribo en esperanto [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>La apriora priskribo ne uziĝos se la priskribo ne disponeblas ĉe la lingvo selektita de la konektita uzanto.
@@ -15,2 +6,9 @@
 <p><u>Speciala lingvo <i>ĉio</i></u>: ĉio ajn ene de [lang=all] estos inkluzivita en la priskribo, kia ajn estu la elektita lingvo de la konektita uzanto.
 Tio ĉefe utilas por inkluzivi HTML/JavaScript-kodo ene de priskribo.</p>
+
+<p><b>Ekzemple</b>:<br>
+<code>[lang=default] apriora priskribo [/lang]<br>
+[lang=eo] priskribo en esperanto [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/es_ES/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/es_ES/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/es_ES/help.lang.html	(revision 29129)
@@ -1,12 +1,4 @@
 <p>Las descripciones multilingües se hacen entre las balizas [lang=xx] y [/lang], O xx es el código de la lengua (por ejemplo fr, en, es, it, de ....)
 Existen también 2 balizas especiales: [lang=default] y [lang=all]</p>
-
-<ul>
-  <li><b>Ejemplo de utilización</b>:<br>
-<code>[lang=default] Descripción por defecto [/lang]<br>
-[lang=fr] Descripción ello francais [/lang]<br>
-[lang=it] Descripción en italiano [/lang]</code>
-</li>
-</ul>
 
 <p>La descripción por defecto será utilizada si la descripción en la lengua del usuario no es definida.
@@ -15,2 +7,8 @@
 <p><u>Baliza  <i>all</i></u>: Todo lo que está situado entre las balizas [lang=all] y [/lang] será incluido en la descripción, cualquiera que sea la lengua del usuario.
 Esto es particularmente práctico para incluir del código HTML o Javascript en una descripción.</p>
+
+<p><b>Ejemplo de utilización</b>:<br>
+<code>[lang=default] Descripción por defecto [/lang]<br>
+[lang=fr] Descripción ello francais [/lang]<br>
+[lang=it] Descripción en italiano [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/fr_FR/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/fr_FR/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/fr_FR/help.lang.html	(revision 29129)
@@ -1,12 +1,4 @@
 <p>Les descriptions multilingues se font entre les balises [lang=xx] et [/lang], ou xx est le code de la langue (par exemple fr, en, es, it, etc....)
 Il existe également 2 balises spéciales: [lang=default] et [lang=all]</p>
-
-<ul>
-  <li><b>Exemple d'utilisation</b>:<br>
-<code>[lang=default] description par défaut [/lang]<br>
-[lang=fr] description en francais [/lang]<br>
-[lang=it] description en italien [/lang]</code>
-</li>
-</ul>
 
 <p>La description par défaut sera utilisée si la description dans la langue de l'utilisateur n'est pas définie.
@@ -15,2 +7,8 @@
 <p><u>Balise <i>all</i></u>: tout ce qui est situé entre les balises [lang=all] et [/lang] sera inclus dans la description, quelle que soit la langue de l'utilisateur.
 Ceci est particulièrement pratique pour inclure du code HTML ou Javascript dans une description.</p>
+
+<p><b>Exemple d'utilisation</b> :<br>
+<code>[lang=default] description par défaut [/lang]<br>
+[lang=fr] description en francais [/lang]<br>
+[lang=it] description en italien [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/fr_FR/help.logged.html
===================================================================
--- /extensions/ExtendedDescription/language/fr_FR/help.logged.html	(revision 29129)
+++ /extensions/ExtendedDescription/language/fr_FR/help.logged.html	(revision 29129)
@@ -0,0 +1,18 @@
+<ul>
+  <li><b>[login-link html=true text="log in[lang=fr]connectez-vous[/lang]"]</b></li>
+</ul>
+
+<p>Ce tag permet d'ajouter n'importe où un lien de connexion avec redirection automatique vers la page courante.<br><br>
+- <code>html</code> (facultatif) si <i>false</i>, la balise ne retourne que l'URL du lien, sans HTML<br>
+- <code>text</code> (facultatif) texte du lien, peut contenir des tags <code>[lang]</code><p>
+
+<ul>
+  <li><b>[logged]</b></li>
+</ul>
+
+<p>Affiche un block de texte selon si l'utilisateur est connecté ou pas.</p>
+
+<p><b>Exemple</b> :<br>
+<code>[logged] C'est un plaisir de vous revoir [/logged]<br>
+[logged=false] Veuillez vous connecter [/logged]</code>
+</p>
Index: /extensions/ExtendedDescription/language/fr_FR/plugin.lang.php
===================================================================
--- /extensions/ExtendedDescription/language/fr_FR/plugin.lang.php	(revision 29128)
+++ /extensions/ExtendedDescription/language/fr_FR/plugin.lang.php	(revision 29129)
@@ -10,4 +10,3 @@
 $lang['Hide elements'] = 'Masquer un élément';
 $lang['Redirect elements'] = 'Rediriger un élément';
-
-?>
+$lang['Login link & logged in block'] = 'Lien de connexion & block authentifié';
Index: /extensions/ExtendedDescription/language/hu_HU/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/hu_HU/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/hu_HU/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Többnyelvű leírások között találhatók a [lang=xx] és [/lang] tag-ek, ahol az  xx a nyelv kódja (például: en, es, fr). Két speciális nyelv van : [lang=default] és [lang=all]</p>
-
-<ul>
-  <li><b>Példa</b>:<br>
-<code>[lang=default] alapértelmezett leírás [/lang]<br>
-[lang=en] angol leírás [/lang]<br>
-[lang=de] német leírás [/lang]</code>
-</li>
-</ul>
 
 <p>Az alapértelmezett nyelvet fogja használni, ha a leírás nem érhető el a csatlakozott felhasználó kiválasztott nyelvén.
@@ -14,2 +6,8 @@
 <p><u>Speciális nyelv <i>all</i></u>: Bármin belül a [lang=all] megjeleníti a leírást, függetlenül a felhasználó nyelvétől.
 Különösen hasznos HTML/JavaScript kódok belsejében lévő leírásoknál.</p>
+
+<p><b>Példa</b>:<br>
+<code>[lang=default] alapértelmezett leírás [/lang]<br>
+[lang=en] angol leírás [/lang]<br>
+[lang=de] német leírás [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/it_IT/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/it_IT/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/it_IT/help.lang.html	(revision 29129)
@@ -1,12 +1,4 @@
 <p>Le descrizioni multilingue si fanno tra i tag [lang=xx] e [/lang], dove xx è il codice della lingua (per esempio fr, en, es, it, ...)
 Esistono anche 2 elementi speciali: [lang=default] e [lang=all]</p>
-
-<ul>
-  <li><b>Esempi d'uso</b>:<br>
-<code>[lang=default] descrizione predefinita [/lang]<br>
-[lang=fr] descrizione in francese [/lang]<br>
-[lang=it] descrizione in italiano [/lang]</code>
-</li>
-</ul>
 
 <p>La descrizione predefinita sarà utilizata se la descrizione nella lingua dell'utente non è definita.
@@ -15,2 +7,8 @@
 <p><u>Tag <i>all</i></u>: Tutto ciò che si trova tra [lang=all] e [/lang] sarà incluso nella descrizione, qualsiasi sia la lingua dell'utente.
 Ciò è molto pratico per includere del codice HTML o Javascript in una descrizione.</p>
+
+<p><b>Esempi d'uso</b>:<br>
+<code>[lang=default] descrizione predefinita [/lang]<br>
+[lang=fr] descrizione in francese [/lang]<br>
+[lang=it] descrizione in italiano [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/lt_LT/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/lt_LT/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/lt_LT/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Daugiakalbiai aprašymai rašomi tarp [lang=xx] ir [/lang] žymų, kur xx yra kalbos kodas (pvz.: lt, en, ru). Taip pat yra dvi specialios "kalbos" : [lang=default] ir [lang=all]</p>
-
-<ul>
-  <li><b>Pavyzdys</b>:<br>
-<code>[lang=default] aprašymas pagal nutylėjimą [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=lt] lietuviškas aprašymas [/lang]</code>
-</li>
-</ul>
 
 <p>Aprašymas pagal nutylėjimą bus naudojamas tuomet, kai nebus aprašymo pasirinkta prisijungusio vartotojo kalba.
@@ -14,2 +6,9 @@
 <p><u>Specliali kalba <i>all</i></u>: viskas, kas yra žymų viduje [lang=all] bus įtraukta į aprašymą, nepriklausomai nuo to, kokia pasirinkta prisijungusio vartotojo kalba.
 Šiuo būdu labai patogu į aprašymą įtraukti HTML/JavaScript kodą.</p>
+
+
+<p><b>Pavyzdys</b>:<br>
+<code>[lang=default] aprašymas pagal nutylėjimą [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=lt] lietuviškas aprašymas [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/lv_LV/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/lv_LV/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/lv_LV/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Apraksti vairākās valodās ir izvietoti starp [lang=xx] un [/lang] iezīmēm, kur xx ir valodas kods (piemēram en, es, fr). Ir arī 2 valodas ar īpašu statusu : [lang=default] and [lang=all]</p>
-
-<ul>
-<li><b>Piemērs</b>:<br>
-<code>[lang=default] apraksts pēc noklusējuma [/lang]<br>
-[lang=en] apraksts angļu valodā [/lang]<br>
-[lang=de] apraksts vācu valodā [/lang]</code>
-</li>
-</ul>
 
 <p>Apraksts pēc noklusējuma tiks lietots, ja apraksts savienojumā esošā lietotāja izvēlētajā valodā nav pieejams.
@@ -14,2 +6,8 @@
 <p><u>Speciālā valoda <i>all</i></u>: jebkas iekšpus [lang=all] tiks ietverts aprakstā neskatoties, kāda ir lietotāja izvēlētā valoda.
 Tas galvenokārt lietderīgi, lai aprakstā ievietotu HTML/JavaScript kodu.</p>
+
+<p><b>Piemērs</b>:<br>
+<code>[lang=default] apraksts pēc noklusējuma [/lang]<br>
+[lang=en] apraksts angļu valodā [/lang]<br>
+[lang=de] apraksts vācu valodā [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/nb_NO/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/nb_NO/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/nb_NO/help.lang.html	(revision 29129)
@@ -1,13 +1,4 @@
 <p>Flerspråklig beskrivelse er plassert mellom [lang=xx] og [/lang] tagger, hvor xx er språk koden (for eksempel en, es, fr).
 Det er også 2 spesial språk : [lang=default] og [lang=all]</p>
-
-<ul>
-  <li><b>Eksampel</b>:<br>
-  <br>
-<code>[lang=default] standard beskrivelse [/lang]<br>
-[lang=en] beskrivelse på engelsk [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Standard beskrivelse vil bli bruktom beskrivelsen ikke er tilgjengelig på den tilkoblede brukers valgte språk.
@@ -16,2 +7,8 @@
 <p><u>Spesial språk <i>alle</i></u>: Alt inne i [lang=all] vil bli inkludert i beskrivelsen, uansett hvilket tilknyttet språ brukeren har.
 Dette er hovedsaklig nyttig for å inkludere HTML/JavaScript kode inne i en beskrivelse.</p>
+
+<p><b>Eksampel</b>:<br>
+<code>[lang=default] standard beskrivelse [/lang]<br>
+[lang=en] beskrivelse på engelsk [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/nl_NL/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/nl_NL/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/nl_NL/help.lang.html	(revision 29129)
@@ -1,12 +1,3 @@
 <p>Meertalige beschrijvingen worden geplaatst tussen [lang=xx] en [/lang] tags, waar xx de taalcode is (bv: en, es, fr). Er zijn ook 2 speciale talen: [lang=default] en [lang=all]</p>
-
-<ul>
-  <li><b>Voorbeeld</b>:<br>
-  <br>
-<code>[lang=default] standaard beschrijving [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>De standaard beschrijving zal gebruikt worden als de beschrijving niet beschikbaar is in de voor de huidige gebruiker geselecteerde taal.
@@ -15,2 +6,8 @@
 <p><u>Special language <i>all</i></u>: alles binnen [lang=all] zal worden ingevoegd ,ongeacht wat de taal van de gebruiker is.
 Dit is handig voor het invoegen van HTML/JavaScript code binnen een beschrijving.</p>
+
+<p><b>Voorbeeld</b>:<br>
+<code>[lang=default] standaard beschrijving [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/nn_NO/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/nn_NO/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/nn_NO/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Flerispråklege skildringar er plassera mellom [lang=xx] og [/lang] taggar, der xx er språkkoden (for example en, es, fr, nn_NO, nb_NO). Det finst og to "spesialspråk" : [lang=default] og [lang=all]</p>
-
-<ul>
-  <li><b>Døme</b>:<br>
-<code>[lang=default] standard skildring [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Standardskildringa vil bli bruka om skildringa ikkje er tilgjengeleg på språket til den pålogga brukaren.
@@ -14,2 +6,8 @@
 <p><u>Spesialspråket <i>all</i></u>: alt innom [lang=all] vill bli inkludera i skildringa, uansett kva for språk brukaren har definera.
 This is mainly useful to include HTML/JavaScript code inside a description.</p>
+
+<p><b>Døme</b>:<br>
+<code>[lang=default] standard skildring [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/pl_PL/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/pl_PL/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/pl_PL/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Multi-językowe opisy umieszczami między tagami [lang=xx] i [/lang] ,gdzie xx to kod języka (na przykład en, es, fr, pl). Są również dwa specjalne tagi językowe : [lang=default] i [lang=all]</p>
-
-<ul>
-<li><b>Przykład</b>:<br>
-<code>[lang=default] opis domyślny [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Opis domyślny używany będzie wtedy, gdy opis nie będzie zdefiniowany tagami w języku połączonego użytkownika.
@@ -14,2 +6,8 @@
 <p><u>Specjalny tag językowy <i>all</i></u>: wszystko co jest zawarte w opisie w obrębie [lang=all] będzie wyświetlane w języku jakim domyślnie posługuje się połączony użytkownik.
 Głównie jest to przydatne do implementowania kodu HTML/JavaScript w opisie.</p>
+
+<p><b>Przykład</b>:<br>
+<code>[lang=default] opis domyślny [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/pt_BR/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/pt_BR/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/pt_BR/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Descrições em vários idiomas são colocados entre [lang=xx] e [/lang] etiquetas, onde xx é o código de idioma (por exemplo en, es, fr). Há também dois idiomas especiais : [lang=default] e [lang=all]</p>
-
-<ul>
-  <li><b>Examplo</b>:<br>
-<code>[lang=default] descrição padrão [/lang]<br>
-[lang=en] descrição em Inglês [/lang]<br>
-[lang=de] descrição em alemão [/lang]</code>
-</li>
-</ul>
 
 <p>A descrição padrão será utilizado se a descrição selecionada não estiver disponível no idioma do usuário conectado.
@@ -14,2 +6,8 @@
 <p><u>Linguagem especial <i>all</i></u>: qualquer coisa dentro [lang=all] será incluído na descrição, qualquer que seja o idioma definido para o usuário conectado.
 Isso é útil principalmente para incluir código HTML/JavaScript dentro de uma descrição.</p>
+
+<p><b>Examplo</b>:<br>
+<code>[lang=default] descrição padrão [/lang]<br>
+[lang=en] descrição em Inglês [/lang]<br>
+[lang=de] descrição em alemão [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/pt_PT/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/pt_PT/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/pt_PT/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Descrições multi-idioma são colocados entre etiquetas [lang=xx] e [/lang], onde xx é o código da língua (por exemplo, en, es, fr,pt). Há também 2 linguagens especiais: [lang=default] e [lang=all]</p>
-
-<ul>
-<li><b>Exemplo</b>: <br>
-<code>[lang=default] default description [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=pt] descrição português [/lang]</code>
-</li>
-</ul>
 
 <p>A descrição padrão será usada se a descrição não está disponível no idioma seleccionado pelo utilizador ligado.
@@ -14,2 +6,8 @@
 <p><u>Idioma especial <i>all</i></u>: nada dentro [lang=all] será incluído na descrição, qualquer que seja o idioma definido pelo utilizador.
 Isto é principalmente útil para incluir códigos HTML / JavaScript numa descrição.</p>
+
+<p><b>Exemplo</b>:<br>
+<code>[lang=default] default description [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=pt] descrição português [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/ru_RU/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/ru_RU/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/ru_RU/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Мультиязычные описания располагаются между тегами [lang=xx] и [/lang], где xx - код языка (например ru, en, es, fr). Также имеются 2 специальных языка: [lang=default] и [lang=all]</p>
-
-<ul>
-  <li><b>Пример</b>:<br>
-<code>[lang=default] описание по умолчанию [/lang]<br>
-[lang=ru] описание на русском [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Описание по умолчанию будет использовано в случае, если отсутствует описание на выбранном текущим пользователем языке.
@@ -14,2 +6,8 @@
 <p><u>Специальный язык <i>all</i></u>: все внутри тега [lang=all] будет включено в описание независимо от выбранного текущим пользователем языка.
 Чаще всего это используется для включения HTML/JavaScript кода в описание.</p>
+
+<p><b>Пример</b>:<br>
+<code>[lang=default] описание по умолчанию [/lang]<br>
+[lang=ru] описание на русском [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/sk_SK/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/sk_SK/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/sk_SK/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Viacjazyčné popisy sú umiestnené medzi [lang=xx] a [/lang] kľúčovými slovami, kde xx je kód jazyka (napríklad en, sk, fr). Sú 2 špeciálne jazyky: [lang=default] a [lang=all]</p>
-
-<ul>
-  <li><b>Príklad</b>:<br>
-<code>[lang=default] východzí popis [/lang]<br>
-[lang=sk] popis v slovenčine [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Východzí popis bude použitý, ak popis v jazyku zvolenom používateľom nie je k dispozícii.
@@ -14,2 +6,8 @@
 <p><u>Špeciálny jazyk <i>all</i></u>: čokoľvek v [lang=all] bude vrátane popisu, kdekoľvek popísané v jazyku, ktorý zvilil používateľ.
 To je hlavne užitočné v HTML/JavaScript popise.</p>
+
+<p><b>Príklad</b>:<br>
+<code>[lang=default] východzí popis [/lang]<br>
+[lang=sk] popis v slovenčine [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/sl_SI/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/sl_SI/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/sl_SI/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Večjezični opisi so umeščeni med oznaki [lang=xx] in [/lang] kjer, xx pomeni kodo jezika (naprimer sl, en, de). Obstajata tudi 2 posebni izbiri jezika : [lang=default] in [lang=all]</p>
-
-<ul>
-  <li><b>Primer</b>:<br>
-<code>[lang=default] privzet opis [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=sl] opis v Slovenščini [/lang]</code>
-</li>
-</ul>
 
 <p>Uporabljen bo privzet opis če ni opisa v jeziku, ki si ga izbere uporabnik.
@@ -14,2 +6,8 @@
 <p><u>Posebna jezikovna izbira <i>all</i></u>: vse v oznaki [lang=all] bo vključeno v opis, ne glede na jezik, ki ga izbere uporabnik.
 To je primerno predvsem za vključitev HTML/JavaScript kode znotraj opisa.</p>
+
+<p><b>Primer</b>:<br>
+<code>[lang=default] privzet opis [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=sl] opis v Slovenščini [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/sv_SE/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/sv_SE/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/sv_SE/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Flerspråkiga beskrivningar placeras mellan [lang=xx] och [/lang] tag, där xx är språkkoden (t.ex. EN, ES, FR). Det finns också 2 särskilda språk : [lang=default] och [lang=all]</p>
-
-<ul>
-  <li><b>Exempel</b>:<br>
-<code>[lang=default] standard beskrivning [/lang]<br>
-[lang=sv] beskrivningen på engelska [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Den förvalda beskrivning ska användas om beskrivningen är inte tillgänglig i den anslutna användaren valda språket.
@@ -14,2 +6,8 @@
 <p><u>speciella språk <i>alla</i></u>: något inuti [lang=all] kommer att ingå i beskrivningen, 0avsätt vad den anslutna användar definierade språk är.
 Detta är främst användbart att inkludera HTML/JavaScript-kod i en beskrivning.</p>
+
+<p><b>Exempel</b>:<br>
+<code>[lang=default] standard beskrivning [/lang]<br>
+[lang=sv] beskrivningen på engelska [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/tr_TR/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/tr_TR/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/tr_TR/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Çoklu Dil açıklamaları [lang=xx] ve [/lang] etiketleri arasında, xx dil kodu olmakla beraber (örnekler en, es, fr). 2 özel dil vardır bunlar : [lang=default]  varsayılan ve [lang=all] hepsi</p>
-
-<ul>
-  <li><b>Örnek</b>:<br>
-<code>[lang=default] varsayılan açıklama [/lang]<br>
-[lang=en] ingilizce açıklama [/lang]<br>
-[lang=de] almanca açıklama [/lang]</code>
-</li>
-</ul>
 
 <p>Bağlı olan kullanıcının seçtiği dildeki açıklama yoksa varsayılan açıklama kullanılır.
@@ -14,2 +6,8 @@
 <p><u>Özel dil <i>all</i></u>: [lang=all] içinde olanlar açıklama olarak tüm bağlı olan kullanıcılar için geçerli açıklama olacaktır.
 Bu çoğunlukla HTML/JavaScript kodları içine açıklama eklemek için faydalıdır.</p>
+
+<p><b>Örnek</b>:<br>
+<code>[lang=default] varsayılan açıklama [/lang]<br>
+[lang=en] ingilizce açıklama [/lang]<br>
+[lang=de] almanca açıklama [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/uk_UA/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/uk_UA/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/uk_UA/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Багатомовний описи розміщено між [lang=xx] та [/lang] теґами, де xx є мовним кодом (для прикладу en, es, fr, uk). Є також 2 спеціальні мови : [lang=default] and [lang=all]</p>
-
-<ul>
-  <li><b>Приклад</b>:<br>
-<code>[lang=default] default description [/lang]<br>
-[lang=en] description in english [/lang]<br>
-[lang=uk] опис на українській [/lang]</code>
-</li>
-</ul>
 
 <p>Опис за замовчуванням буде використовуватися, якщо опис недоступний в вибраної користувачем мови.
@@ -14,2 +6,8 @@
 <p><u>Спеціальні мови <i>всі</i></u>: все, що всередині [lang=all] будуте включено в опис, все що пов'язане з мовою певного користувача.
 Це головним чином корисно, щоб включати код HTML/JavaScript усередині опису.</p>
+
+<p><b>Приклад</b>:<br>
+<code>[lang=default] default description [/lang]<br>
+[lang=en] description in english [/lang]<br>
+[lang=uk] опис на українській [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/vi_VN/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/vi_VN/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/vi_VN/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>Mô tả đa ngôn ngữ được đặt giữa thẻ [lang=xx] và [/lang], với xx mã ngôn ngữ (ví dụ en, vn, fr). Có 2 ngôn ngữ chuyên biệt: [lang=default] và [lang=all]</p>
-
-<ul>
-<li><b>Ví dụ</b>:<br>
-<code>[lang=default] mô tả mặc định [/lang]<br>
-[lang=en] mô tả bằng Tiếng Anh [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>Mô tả mặc định sẽ được sử dụng nếu phần mô tả không dùng được trong ngôn ngữ được lựa chọn của người dùng đã kết nối. 
@@ -14,2 +6,8 @@
 <p><u>Từ khóa đặc biệt <i>all</i></u>: bất kỳ từ nào thuộc trong chỉ định [lang=all] sẽ được bao gồm trong mô tả, và bất kỳ từ nào mà ngôn ngữ được định nghĩa của người dùng đã kết nối.
 Đây là lợi ích chính nhằm kết hợp mã HTML/JavaScript bên trong một mô tả.</p>
+
+<p><b>Ví dụ</b>:<br>
+<code>[lang=default] mô tả mặc định [/lang]<br>
+[lang=en] mô tả bằng Tiếng Anh [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/language/zh_CN/help.lang.html
===================================================================
--- /extensions/ExtendedDescription/language/zh_CN/help.lang.html	(revision 29128)
+++ /extensions/ExtendedDescription/language/zh_CN/help.lang.html	(revision 29129)
@@ -1,11 +1,3 @@
 <p>多语言描述可放在[lang=xx] 和 [/lang] 标签之间, 其中 xx 是语言代码（如 en,es,cn,fr)。另外还有2个特别的语言: [lang=default] 和 [lang=all]</p>
-
-<ul>
-  <li><b>例如</b>:<br>
-<code>[lang=default] 默认描述 [/lang]<br>
-[lang=en] description in English [/lang]<br>
-[lang=de] deutsche Beschreibung [/lang]</code>
-</li>
-</ul>
 
 <p>
@@ -14,2 +6,8 @@
 
 <p><u> 特别语言<i>all</i></u>: 所有在 [lang=all] 标签里的将被包含进描述，不论用户指定了什么语言。这个主要的用处是对于 HTML/JavaScript 等代码在描述里的显示。</p>
+
+<p><b>例如</b>:<br>
+<code>[lang=default] 默认描述 [/lang]<br>
+[lang=en] description in English [/lang]<br>
+[lang=de] deutsche Beschreibung [/lang]</code>
+</p>
Index: /extensions/ExtendedDescription/template/admin.tpl
===================================================================
--- /extensions/ExtendedDescription/template/admin.tpl	(revision 29128)
+++ /extensions/ExtendedDescription/template/admin.tpl	(revision 29129)
@@ -29,2 +29,7 @@
   {$EXTDESC_HELP.redirect}
 </fieldset>
+
+<fieldset>
+  <legend>{'Login link & logged in block'|translate}</legend>
+  {$EXTDESC_HELP.logged}
+</fieldset>
Index: /extensions/ExtendedDescription/template/slider.tpl
===================================================================
--- /extensions/ExtendedDescription/template/slider.tpl	(revision 29128)
+++ /extensions/ExtendedDescription/template/slider.tpl	(revision 29129)
@@ -28,5 +28,5 @@
     {/if}
 
-    <img {if $derivative->is_cached()}src="{$derivative->get_url()}"{else}src="" data-src="{$derivative->get_url()}"{/if} alt="{$thumbnail.TN_ALT}" {$derivative->get_size_htm()} {if $show_title}title="<a href='{$thumbnail.URL}'>{$thumbnail.NAME|replace:'"':"'"}</a>"{/if} {if $SLIDER.control_thumbs}data-thumb="{$derivative_thumb}"{/if}>
+    <img {if $derivative->is_cached()}src="{$derivative->get_url()}"{else}src="" data-src="{$derivative->get_url()}"{/if} alt="{$thumbnail.TN_ALT}" {$derivative->get_size_htm()} {if $SLIDER.title}title="<a href='{$thumbnail.URL}'>{$thumbnail.NAME|replace:'"':"'"}</a>"{/if} {if $SLIDER.control_thumbs}data-thumb="{$derivative_thumb}"{/if}>
 
     {assign var=derivative_size value=$derivative->get_size()}

Index: /extensions/ExtendedDescription/include/functions.inc.php
===================================================================
--- /extensions/ExtendedDescription/include/functions.inc.php	(revision 29128)
+++ /extensions/ExtendedDescription/include/functions.inc.php	(revision 29129)
@@ -5,5 +5,5 @@
  * Return html code for  category thumb
  */
-function get_cat_thumb($elem_id)
+function extdesc_get_cat_thumb($elem_id)
 {
   global $template, $user;
@@ -78,8 +78,8 @@
  * @int    album: album to display picture in    (default: null)
  * @string size:  picture size                   (default: M)
- * @string html:  return complete html structure (default: yes)
- * @string link:  add a link to the picture      (default: yes)
- */
-function get_photo_sized($param)
+ * @bool   html:  return complete html structure (default: true)
+ * @bool   link:  add a link to the picture      (default: true)
+ */
+function extdesc_get_photo_sized($param)
 {
   global $template;
@@ -89,6 +89,6 @@
     'album' => array('\d+', null),
     'size' =>  array('SQ|TH|XXS|XS|S|M|L|XL|XXL', 'M'),
-    'html' =>  array('yes|no', 'yes'),
-    'link' =>  array('yes|no', 'yes'),
+    'html' =>  array('boolean', true),
+    'link' =>  array('boolean', true),
     );
 
@@ -99,6 +99,4 @@
 
   // parameters
-  $params['link'] = $params['link']=='no' ? false : true;
-  $params['html'] = $params['html']=='no' ? false : true;
   $deriv_type = extdesc_get_deriv_type($params['size']);
 
@@ -171,6 +169,6 @@
  * @int    album: select picture from this album (default: all)
  * @string size:  picture size                   (default: M)
  * @string html:  return complete html structure (default: yes)
  * @string link:  add a link to the picture      (default: no)
  */
 function extdesc_get_random_photo($param)
@@ -180,6 +178,6 @@
     'cat' =>   array('\d+', null), // historical
     'size' =>  array('SQ|TH|XXS|XS|S|M|L|XL|XXL', 'M'),
-    'html' =>  array('yes|no', 'yes'),
-    'link' =>  array('yes|no', 'no'),
+    'html' =>  array('boolean', true),
+    'link' =>  array('boolean', false),
     );
 
@@ -224,5 +222,5 @@
   {
     list($params['id'], $params['album']) = pwg_db_fetch_row($result);
-    return get_photo_sized($params);
+    return extdesc_get_photo_sized($params);
   }
 
@@ -241,12 +239,12 @@
  * @string size:      picture size                      (default: M)
  * @int    speed:     slideshow duration                (default: 3)
  * @string title:     display picture name              (default: no)
  * @string effect:    transition effect                 (default: fade)
  * @string arrows:    display navigation arrows         (default: yes)
  * @string control:   display navigation bar            (default: yes)
  * @string elastic:   adapt slider size to each picture (default: yes)
  * @int thumbs_size:  size of thumbnails if control=thumb (default: 80)
  */
-function get_slider($param)
+function extdesc_get_slider($param)
 {
   global $template, $conf;
@@ -255,13 +253,13 @@
     'album' =>     array('\d+', null),
     'nb_images' => array('\d+', 10),
-    'random' =>    array('yes|no', 'no'),
+    'random' =>    array('boolean', false),
     'list' =>      array('[\d,]+', null),
     'size' =>      array('SQ|TH|XXS|XS|S|M|L|XL|XXL', 'M'),
     'speed' =>     array('\d+', 5),
-    'title' =>     array('yes|no', 'no'),
+    'title' =>     array('boolean', false),
     'effect' =>    array('[a-zA-Z]+', 'fade'),
-    'arrows' =>    array('yes|no', 'yes'),
-    'control' =>   array('yes|no|thumb', 'yes'),
-    'elastic' =>   array('yes|no', 'yes'),
+    'arrows' =>    array('boolean', true),
+    'control' =>   array('yes|no|true|false|thumb', true),
+    'elastic' =>   array('boolean', true),
     'thumbs_size' => array('\d+', 80),
     );
@@ -280,16 +278,12 @@
   if ($params['control'] === 'thumb')
   {
-    $params['control'] = 'yes';
+    $params['control'] = true;
     $params['control_thumbs'] = true;
   }
   else
   {
+    $params['control'] = filter_var($params['control'], FILTER_VALIDATE_BOOLEAN);
     $params['control_thumbs'] = false;
   }
-  $params['arrows'] = $params['arrows']==='yes';
-  $params['control'] = $params['control']==='yes';
-  $params['elastic'] = $params['elastic']==='yes';
-  $params['title'] = $params['title']==='yes';
-  $params['random'] = $params['random']==='yes';
 
   $tpl_vars = $params;
@@ -406,4 +400,43 @@
 
 /**
+ * Return html code for login link
+ *
+ * @bool   html: return complete html structure (default: true)
+ * @string text: link text, translatable        (default: Login)
+ */
+function extdesc_get_login_link($param)
+{
+  $default_params = array(
+    'html' => array('boolean', true),
+    'text' => array('".*"', ''),
+    );
+
+  $params = extdesc_parse_parameters($param, $default_params);
+  
+  $url =
+      get_root_url().'identification.php?redirect='
+      .urlencode(urlencode($_SERVER['REQUEST_URI']));
+  
+  if ($params['html'])
+  {
+    if (empty($params['text']))
+    {
+      $params['text'] = l10n('Login');
+    }
+    else
+    {
+      $params['text'] = get_user_language_desc(mb_substr($params['text'], 1, -1));
+    }
+  
+    return '<a href="' . $url . '">' . $params['text'] . '</a>';
+  }
+  else
+  {
+    return $url;
+  }
+  
+}
+
+/**
  * Parse tags parameters
  */
@@ -419,7 +452,18 @@
   foreach ($default_params as $name => $value)
   {
+    $is_bool = false;
+    if ($value[0] == 'boolean')
+    {
+      $is_bool = true;
+      $value[0] = 'yes|no|true|false';
+    }
+    
     if (preg_match('#'.$name.'=('.$value[0].')#', $param, $matches))
     {
       $params[$name] = $matches[1];
+      if ($is_bool)
+      {
+        $params[$name] = filter_var($params[$name], FILTER_VALIDATE_BOOLEAN);
+      }
     }
     else
@@ -171,6 +169,6 @@
  * @int    album: select picture from this album (default: all)
  * @string size:  picture size                   (default: M)
- * @string html:  return complete html structure (default: yes)
- * @string link:  add a link to the picture      (default: no)
+ * @bool   html:  return complete html structure (default: true)
+ * @bool   link:  add a link to the picture      (default: false)
  */
 function extdesc_get_random_photo($param)
@@ -241,12 +239,12 @@
  * @string size:      picture size                      (default: M)
  * @int    speed:     slideshow duration                (default: 3)
- * @string title:     display picture name              (default: no)
+ * @bool   title:     display picture name              (default: false)
  * @string effect:    transition effect                 (default: fade)
@@ -241,12 +239,12 @@
  * @string effect:    transition effect                 (default: fade)
- * @string arrows:    display navigation arrows         (default: yes)
- * @string control:   display navigation bar            (default: yes)
- * @string elastic:   adapt slider size to each picture (default: yes)
+ * @bool   arrows:    display navigation arrows         (default: true)
+ * @string control:   display navigation bar            (default: true)
+ * @bool   elastic:   adapt slider size to each picture (default: true)
  * @int thumbs_size:  size of thumbnails if control=thumb (default: 80)
  */